==> nextcloud-app-notes-4.11.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/eu.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Oharrak",
    "Create new note" : "Sortu ohar berria",
    "More notes" : "Ohar gehiago",
    "Reading notes from filesystem has failed." : "Fitxategi-sistemaren ohar-irakurketak huts egin du.",
    "Error" : "Errorea",
    "New note" : "Ohar berria",
    "Distraction-free notes and writing" : "Distrakziorik gabeko oharrak eta idazkiak",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Oharrak aplikazioa distrakziorik gabeko oharrak hartzeko aplikazioa da [Nextcloud](https://www.nextcloud.com/). Hobeto antolatzeko kategoriak eskaintzen ditu eta [Markdown](https://en.wikipedia.org/wiki/Markdown) sintaxia erabiliz formateatzea onartzen du. Oharrak fitxategi gisa gordetzen dira zure Nextcloud-en, Nextcloud bezero guztiekin ikusi eta editatu ahal izateko. Gainera, [REST API] bereizi batek (https://github.com/nextcloud/notes/blob/master/docs/api/README.md) hirugarrenen aplikazioetan erraz integratzeko aukera ematen du (gaur egun, oharren aplikazioak daude [Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios) eta [kontsola](https://git. danielmoch.com/nncli/about) zure Nextcloud-eko oharretara sarbide egokia ahalbidetzen dutenak). Ezaugarri gehigarrien artean dago oharrak gogoko bezala markatzeko aukera.",
    "Notes settings" : "Oharren ezarpenak",
    "Please see Nextcloud server log for details." : "Ikus Nextcloud zerbitzari-egunkaria xehetasunak eskuratzeko.",
    "Deleted {title}" : "{title} ezabatuta",
    "Undo Delete" : "Desegin ezabatzea",
    "Note recovered" : "Oharra berreskuratuta",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Gorde gabeko oharrak daude. Orrialdetik irtetean aldaketa guztiak galduko dira!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{Number} ohar ezabatu dira","{number} ohar ezabatuta"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} ohar berreskuratuta","{number} ohar berreskuratuta"],
    "Basics" : "Oinarrizkoak",
    "Write down your thoughts without any distractions." : "Idatzi zure ideiak distrakziorik gabe",
    "Organize your notes in categories." : "Antolatu zure oharrak kategoriatan.",
    "Notes path" : "Oharren bide-izena",
    "Folder to store your notes" : "Zure oharrak gordetzeko karpeta",
    "Root directory" : "Erro karpeta",
    "File extension" : "Fitxategi-luzapena",
    "File extension for new notes" : "Ohar berrien fitxategi-luzapena",
    "Display mode" : "Erakuste-modua",
    "Display mode for notes" : "Erakusketa modua oharrentzat",
    "Shortcuts" : "Lasterbideak",
    "Use shortcuts to quickly navigate this app." : "Erabili lasterbideak aplikazio hau nabigatzeko.",
    "Shortcut" : "Lasterbidea",
    "Action" : "Ekintza",
    "Mobile apps" : "Aplikazio mugikorrak",
    "User defined" : "Erabiltzaile definitua",
    "Open in rich text mode" : "Ireki testu aberastu moduan",
    "Open in edit mode" : "Ireki edizio moduan",
    "Open in preview mode" : "Ireki aurrebista moduan",
    "CTRL" : "KTRL",
    "Make the selection bold" : "Egin hautaketa lodia",
    "Make the selection italic" : "Egin hautaketa etzana",
    "Wrap the selection in quotes" : "Jarri komatxoak hautaketari",
    "ALT" : "ALT",
    "The selection will be turned into monospace" : "Hautaketa zuriune bakarrekoa egin",
    "Remove any styles from the selected text" : "Kendu estiloak hautatutako testuan",
    "Makes the current line a list element" : "Uneko lerroa zerrenda elementu bihurtu",
    "Makes the current line a list element with a number" : "Uneko lerroa zenbakizko zerrenda elementu bihurtu",
    "Toggle heading for current line" : "Aldatu uneko lerroaren goiburua",
    "SHIFT" : "MAIUS",
    "Set the current line as a big heading" : "Ezarri uneko lerroa goiburu handi gisa",
    "Insert link" : "Txertatu esteka",
    "Insert image" : "Txertatu irudia",
    "Switch between editor and viewer" : "Aldatu editore eta ikustailearen artean",
    "All notes" : "Ohar guztiak",
    "Categories" : "Kategoriak",
    "Create a sample note with Markdown" : "Sortu lagin-ohar bat Markdown-ekin",
    "No notes yet" : "Ez dago oharrik",
    "Upload image" : "Igo irudia",
    "Select an image" : "Hautatu irudi bat",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ezin duzu hautatu irudirik zure ohar karpetatik kanpo. Zure ohar karpeta hau da: {folder}",
    "Wrong image" : "Okerreko irudia",
    "The file was not uploaded. Check your server logs." : "Fitxategia ez da igo. Egiaztatu zure zerbitzariaren erregistroak.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instalatu mugikorrerako aplikazioa zure oharrak edonondik atzitzeko.",
    "Android app: {notes}" : "Android aplikazioa: {notes}",
    "iOS app: {notes}" : "iOS aplikazioa: {notes}",
    "Rich text editor" : "Testu aberastuaren editore",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Orain, erabiltzeko erraza eta distrakziorik gabeko testu aberastuko editorea erabil dezakezu. Markdown markarik ikusi gabe oharrak editatzeko aukera ematen du.",
    "This option can also be changed later on in the Notes app settings." : "Aukera hau geroago ere alda daiteke Oharrak aplikazioaren ezarpenetan.",
    "Keep plain Markdown editor" : "Mantendu Markdown editore arrunta",
    "Use rich editor" : "Erabili editore aberastua",
    "Share" : "Share",
    "Change category" : "Aldatu kategoria",
    "Rename" : "Izena aldatu",
    "Rename note" : "Berrizendatu oharra",
    "Delete note" : "Ezabatu oharra",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Add to favorites" : "Gehitu gogokoetan",
    "Error while renaming note." : "Errorea oharra berrizendatzean.",
    "Error during preparing note for deletion." : "Errorea oharra ezabatzeko prestatzean.",
    "The note has been changed in another session. Please choose which version should be saved." : "Oharra beste saio batean aldatu da. Aukeratu zein bertsio gorde behar den.",
    "Use version from server" : "Erabili zerbitzariko bertsioa",
    "Use current version" : "Erabili uneko bertsioa",
    "Empty note" : "Ohar hutsa",
    "Write …" : "Idatzi …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editatu",
    "Preview" : "Aurrebista",
    "Exit full screen" : "Irten pantaila osotik",
    "Full screen" : "Pantaila osoa",
    "Note is read-only. You cannot change it." : "Oharra irakurtzeko soilik da. Ezin duzu aldatu.",
    "Save failed. Click to retry." : "Huts egin du gordetzean. Egin klik berriro saiatzeko.",
    "Update conflict. Click for resolving manually." : "Eguneraketa gatazka. Egin klik eskuz ebazteko.",
    "Error from Nextcloud server: {msg}" : "Nextcloud zerbitzariaren errorea: {msg}",
    "Search for notes" : "Bilatu oharrak",
    "Loading …" : "Kargatzen...",
    "Find in all categories" : "Bilatu kategoria guztietan",
    "Today" : "Gaur",
    "Yesterday" : "Atzo",
    "This week" : "Aste honetan",
    "Last week" : "Azken astean",
    "This month" : "Hilabete honetan",
    "Last month" : "Azken hilabetean",
    "Use Markdown markups to style your text." : "Erabili Markdown markatzea zure testuari estiloa emateko.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Hasi ohar bat idazten aplikazioaren nabigazioko “{newnote}” aukeran klik eginez.",
    "Note not found." : "Oharra ez da aurkitu.",
    "Note is locked." : "Oharra blokeatuta dago.",
    "Insufficient storage." : "Ez dago nahikoa biltegi.",
    "See JavaScript console and server log for details." : "Ikusi JavaScript kontsola eta zerbitzariaren egunkariak xehetasunetarako.",
    "Updating settings has failed." : "Ezarpenak eguneratzeak huts egin du.",
    "Fetching notes for dashboard has failed." : "Panelerako oharrak eskuratzeak huts egin du.",
    "Fetching notes has failed." : "Oharrak eskuratzeak huts egin du.",
    "Fetching note {id} has failed." : "{id} oharrak eskuratzeak huts egin du.",
    "Refreshing note {id} has failed." : "{id} oharra freskatzeak huts egin du.",
    "Renaming note {id} has failed." : "{id} oharra berrizendatzeak huts egin du.",
    "Creating new note has failed." : "Ohar berria sortzeak huts egin du.",
    "Saving note {id} has failed." : "{id} oharra gordetzeak huts egin du.",
    "Updating title for note {id} has failed." : "{id} oharrari izenburua eguneratzeak huts egin du.",
    "Undo delete has failed for note {title}." : "{title} oharra ezabatzea desegiteak huts egin du.",
    "Deleting note {id} has failed." : "{id} oharra ezabatzeak huts egin du.",
    "Toggling favorite for note {id} has failed." : "{id} oharrari gogoko egoera txandakatzeak huts egin du.",
    "Updating the note's category has failed. Is the target directory writable?" : "Oharraren kategoria eguneratzeak huts egin du. Helburuko direktorioan idatzi al daiteke?",
    "Updating the category for note {id} has failed." : "{id} oharraren kategoria eguneratzeak huts egin du.",
    "Uncategorized" : "Sailkatu gabe",
    "Sample note" : "Adibidezko oharra",
    "15 January 2021, via Nextcloud Notes" : "2021eko urtarrilak 15, Nextcloud Notes bidez",
    "Me, you, and all our friends!" : "Ni, zu, eta zure lagun guztiak!",
    "Tasks" : "Zereginak",
    "Write nice todo lists" : "Idatzi egiteko zerrenda onak",
    "Buy Fries" : "Erosi patata frijituak",
    "Birthdays" : "Urtebetetzeak",
    "Jen, in three days!" : "Jen, hiru egunetan!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Berrikusi pausoak",
    "Turn PC off" : "Itzali PCa",
    "Turn PC on" : "Piztu PCa",
    "Then call IT" : "eta deitu IKT",
    "Quotes" : "Oharrak",
    "Nextcloud, a safe home for all your data" : "Nextcloud, toki seguru bat zure datu guztientzat",
    "Development Mode" : "Garapen modua",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Oharrak aplikazioa garapeneko iturburutik instalatu zela dirudi. Horren ordez, instalatu <a href=\"%1$s\">Nextcloud aplikazio biltegi</a> ofizialetik. Oharrak aplikazioa zuk zeuk eraiki nahi baduzu, jarraitu <a href=\"%2$s\">garatzaileentzako jarraibideak</a>."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-4.12.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/eu.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Oharrak",
    "Create new note" : "Sortu ohar berria",
    "More notes" : "Ohar gehiago",
    "Reading notes from filesystem has failed." : "Fitxategi-sistemaren ohar-irakurketak huts egin du.",
    "Error" : "Errorea",
    "New note" : "Ohar berria",
    "Distraction-free notes and writing" : "Distrakziorik gabeko oharrak eta idazkiak",
    "Deleted {title}" : "{title} ezabatuta",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{Number} ohar ezabatu dira","{number} ohar ezabatuta"],
    "Undo Delete" : "Desegin ezabatzea",
    "Note recovered" : "Oharra berreskuratuta",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} ohar berreskuratuta","{number} ohar berreskuratuta"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "Gorde gabeko oharrak daude. Orrialdetik irtetean aldaketa guztiak galduko dira!",
    "Notes settings" : "Oharren ezarpenak",
    "Please see Nextcloud server log for details." : "Ikus Nextcloud zerbitzari-egunkaria xehetasunak eskuratzeko.",
    "Preview" : "Aurrebista",
    "Make the selection bold" : "Egin hautaketa lodia",
    "Make the selection italic" : "Egin hautaketa etzana",
    "Wrap the selection in quotes" : "Jarri komatxoak hautaketari",
    "The selection will be turned into monospace" : "Hautaketa zuriune bakarrekoa egin",
    "Remove any styles from the selected text" : "Kendu estiloak hautatutako testuan",
    "Makes the current line a list element" : "Uneko lerroa zerrenda elementu bihurtu",
    "Makes the current line a list element with a number" : "Uneko lerroa zenbakizko zerrenda elementu bihurtu",
    "Toggle heading for current line" : "Aldatu uneko lerroaren goiburua",
    "Set the current line as a big heading" : "Ezarri uneko lerroa goiburu handi gisa",
    "Insert link" : "Txertatu esteka",
    "Insert image" : "Txertatu irudia",
    "Switch between editor and viewer" : "Aldatu editore eta ikustailearen artean",
    "Pick a notes folder" : "Aukeratu ohar karpeta bat",
    "Set notes folder" : "Ezarri oharren karpeta",
    "Display" : "Bistaratzea",
    "File extension" : "Fitxategi-luzapena",
    "Mobile apps" : "Aplikazio mugikorrak",
    "Shortcuts" : "Lasterbideak",
    "All notes" : "Ohar guztiak",
    "Categories" : "Kategoriak",
    "Create a sample note with Markdown" : "Sortu lagin-ohar bat Markdown-ekin",
    "No notes yet" : "Ez dago oharrik",
    "Select an image" : "Hautatu irudi bat",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ezin duzu hautatu irudirik zure ohar karpetatik kanpo. Zure ohar karpeta hau da: {folder}",
    "Wrong image" : "Okerreko irudia",
    "The file was not uploaded. Check your server logs." : "Fitxategia ez da igo. Egiaztatu zure zerbitzariaren erregistroak.",
    "Upload image" : "Igo irudia",
    "Rich text editor" : "Testu aberastuaren editore",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Orain, erabiltzeko erraza eta distrakziorik gabeko testu aberastuko editorea erabil dezakezu. Markdown markarik ikusi gabe oharrak editatzeko aukera ematen du.",
    "This option can also be changed later on in the Notes app settings." : "Aukera hau geroago ere alda daiteke Oharrak aplikazioaren ezarpenetan.",
    "Keep plain Markdown editor" : "Mantendu Markdown editore arrunta",
    "Use rich editor" : "Erabili editore aberastua",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Add to favorites" : "Gehitu gogokoetan",
    "Error while renaming note." : "Errorea oharra berrizendatzean.",
    "Error during preparing note for deletion." : "Errorea oharra ezabatzeko prestatzean.",
    "Share" : "Share",
    "Change category" : "Aldatu kategoria",
    "Rename" : "Izena aldatu",
    "Rename note" : "Berrizendatu oharra",
    "Delete note" : "Ezabatu oharra",
    "Error from Nextcloud server: {msg}" : "Nextcloud zerbitzariaren errorea: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "Oharra beste saio batean aldatu da. Aukeratu zein bertsio gorde behar den.",
    "Use version from server" : "Erabili zerbitzariko bertsioa",
    "Use current version" : "Erabili uneko bertsioa",
    "Empty note" : "Ohar hutsa",
    "Write …" : "Idatzi …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editatu",
    "Exit full screen" : "Irten pantaila osotik",
    "Full screen" : "Pantaila osoa",
    "Note is read-only. You cannot change it." : "Oharra irakurtzeko soilik da. Ezin duzu aldatu.",
    "Save failed. Click to retry." : "Huts egin du gordetzean. Egin klik berriro saiatzeko.",
    "Update conflict. Click for resolving manually." : "Eguneraketa gatazka. Egin klik eskuz ebazteko.",
    "Today" : "Gaur",
    "Yesterday" : "Atzo",
    "This week" : "Aste honetan",
    "Last week" : "Azken astean",
    "This month" : "Hilabete honetan",
    "Last month" : "Azken hilabetean",
    "Search for notes" : "Bilatu oharrak",
    "Loading …" : "Kargatzen...",
    "Find in all categories" : "Bilatu kategoria guztietan",
    "Write down your thoughts without any distractions." : "Idatzi zure ideiak distrakziorik gabe",
    "Use Markdown markups to style your text." : "Erabili Markdown markatzea zure testuari estiloa emateko.",
    "Organize your notes in categories." : "Antolatu zure oharrak kategoriatan.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Hasi ohar bat idazten aplikazioaren nabigazioko “{newnote}” aukeran klik eginez.",
    "Note not found." : "Oharra ez da aurkitu.",
    "Note is locked." : "Oharra blokeatuta dago.",
    "Insufficient storage." : "Ez dago nahikoa biltegi.",
    "See JavaScript console and server log for details." : "Ikusi JavaScript kontsola eta zerbitzariaren egunkariak xehetasunetarako.",
    "Updating settings has failed." : "Ezarpenak eguneratzeak huts egin du.",
    "Fetching notes for dashboard has failed." : "Panelerako oharrak eskuratzeak huts egin du.",
    "Fetching notes has failed." : "Oharrak eskuratzeak huts egin du.",
    "Fetching note {id} has failed." : "{id} oharrak eskuratzeak huts egin du.",
    "Refreshing note {id} has failed." : "{id} oharra freskatzeak huts egin du.",
    "Renaming note {id} has failed." : "{id} oharra berrizendatzeak huts egin du.",
    "Creating new note has failed." : "Ohar berria sortzeak huts egin du.",
    "Saving note {id} has failed." : "{id} oharra gordetzeak huts egin du.",
    "Updating title for note {id} has failed." : "{id} oharrari izenburua eguneratzeak huts egin du.",
    "Undo delete has failed for note {title}." : "{title} oharra ezabatzea desegiteak huts egin du.",
    "Deleting note {id} has failed." : "{id} oharra ezabatzeak huts egin du.",
    "Toggling favorite for note {id} has failed." : "{id} oharrari gogoko egoera txandakatzeak huts egin du.",
    "Updating the note's category has failed. Is the target directory writable?" : "Oharraren kategoria eguneratzeak huts egin du. Helburuko direktorioan idatzi al daiteke?",
    "Updating the category for note {id} has failed." : "{id} oharraren kategoria eguneratzeak huts egin du.",
    "Uncategorized" : "Sailkatu gabe",
    "Sample note" : "Adibidezko oharra",
    "15 January 2021, via Nextcloud Notes" : "2021eko urtarrilak 15, Nextcloud Notes bidez",
    "Me, you, and all our friends!" : "Ni, zu, eta zure lagun guztiak!",
    "Tasks" : "Zereginak",
    "Write nice todo lists" : "Idatzi egiteko zerrenda onak",
    "Buy Fries" : "Erosi patata frijituak",
    "Birthdays" : "Urtebetetzeak",
    "Jen, in three days!" : "Jen, hiru egunetan!",
    "Moss, 21.03.1973" : "Moss, 21.03.1973",
    "Roy, 1979" : "Roy, 1979",
    "Review Steps" : "Berrikusi pausoak",
    "Turn PC off" : "Itzali PCa",
    "Turn PC on" : "Piztu PCa",
    "Then call IT" : "eta deitu IKT",
    "Quotes" : "Oharrak",
    "Nextcloud, a safe home for all your data" : "Nextcloud, toki seguru bat zure datu guztientzat",
    "Development Mode" : "Garapen modua",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Oharrak aplikazioa garapeneko iturburutik instalatu zela dirudi. Horren ordez, instalatu <a href=\"%1$s\">Nextcloud aplikazio biltegi</a> ofizialetik. Oharrak aplikazioa zuk zeuk eraiki nahi baduzu, jarraitu <a href=\"%2$s\">garatzaileentzako jarraibideak</a>."
},
"nplurals=2; plural=(n != 1);");
